summaryrefslogtreecommitdiffhomepage
path: root/cheatsheet/raylib_structs.c
diff options
context:
space:
mode:
authorRay <[email protected]>2021-10-18 00:06:41 +0200
committerRay <[email protected]>2021-10-18 00:06:41 +0200
commit7f0e6dee5c99b14a104ee55fd7699723771d2a9b (patch)
tree3119b56d8c8bc7c9e27879163397d7f66cb8e0e9 /cheatsheet/raylib_structs.c
parentbe0adede500a565bbdd4976e361549f6fdc7ef85 (diff)
downloadraylib.com-7f0e6dee5c99b14a104ee55fd7699723771d2a9b.tar.gz
raylib.com-7f0e6dee5c99b14a104ee55fd7699723771d2a9b.zip
Update cheatsheet
Diffstat (limited to 'cheatsheet/raylib_structs.c')
-rw-r--r--cheatsheet/raylib_structs.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/cheatsheet/raylib_structs.c b/cheatsheet/raylib_structs.c
index 7f7e7a2..2e9ff08 100644
--- a/cheatsheet/raylib_structs.c
+++ b/cheatsheet/raylib_structs.c
@@ -13,7 +13,7 @@
// NOTE: Data stored in GPU memory (VRAM)
struct RenderTexture; // RenderTexture type, for texture rendering
struct NPatchInfo; // N-Patch layout info
- struct CharInfo; // Font character info
+ struct GlyphInfo; // Font character glyph info
struct Font; // Font type, includes texture and chars data
struct Camera; // Camera type, defines 3d camera position/orientation
@@ -27,7 +27,7 @@
struct BoneInfo; // Bone information
struct ModelAnimation; // Model animation data (bones and frames)
struct Ray; // Ray type (useful for raycast)
- struct RayHitInfo; // Raycast hit information
+ struct RayCollision; // Raycast hit information
struct BoundingBox; // Bounding box type for 3d mesh
struct Wave; // Wave type, defines audio wave data